/* DomNode.c generated by valac 0.34.13, the Vala compiler
 * generated from DomNode.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */
/*
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>


#define GXML_TYPE_DOM_EVENT_TARGET (gxml_dom_event_target_get_type ())
#define GXML_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTarget))
#define GXML_IS_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_TARGET))
#define GXML_DOM_EVENT_TARGET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTargetIface))

typedef struct _GXmlDomEventTarget GXmlDomEventTarget;
typedef struct _GXmlDomEventTargetIface GXmlDomEventTargetIface;

#define GXML_TYPE_DOM_EVENT_LISTENER (gxml_dom_event_listener_get_type ())
#define GXML_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListener))
#define GXML_IS_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_LISTENER))
#define GXML_DOM_EVENT_LISTENER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListenerIface))

typedef struct _GXmlDomEventListener GXmlDomEventListener;
typedef struct _GXmlDomEventListenerIface GXmlDomEventListenerIface;

#define GXML_TYPE_DOM_EVENT (gxml_dom_event_get_type ())
#define GXML_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEvent))
#define GXML_IS_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT))
#define GXML_DOM_EVENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEventIface))

typedef struct _GXmlDomEvent GXmlDomEvent;
typedef struct _GXmlDomEventIface GXmlDomEventIface;

#define GXML_TYPE_DOM_TIME_STAMP (gxml_dom_time_stamp_get_type ())
#define GXML_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStamp))
#define GXML_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))
#define GXML_IS_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_IS_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_DOM_TIME_STAMP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))

typedef struct _GXmlDomTimeStamp GXmlDomTimeStamp;
typedef struct _GXmlDomTimeStampClass GXmlDomTimeStampClass;

#define GXML_DOM_EVENT_TYPE_PHASE (gxml_dom_event_phase_get_type ())

#define GXML_TYPE_DOM_NODE (gxml_dom_node_get_type ())
#define GXML_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE, GXmlDomNode))
#define GXML_IS_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE))
#define GXML_DOM_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE, GXmlDomNodeIface))

typedef struct _GXmlDomNode GXmlDomNode;
typedef struct _GXmlDomNodeIface GXmlDomNodeIface;

#define GXML_DOM_NODE_TYPE_DOCUMENT_POSITION (gxml_dom_node_document_position_get_type ())

#define GXML_DOM_NODE_TYPE_NODE_TYPE (gxml_dom_node_node_type_get_type ())

#define GXML_TYPE_DOM_PARENT_NODE (gxml_dom_parent_node_get_type ())
#define GXML_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNode))
#define GXML_IS_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PARENT_NODE))
#define GXML_DOM_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNodeIface))

typedef struct _GXmlDomParentNode GXmlDomParentNode;
typedef struct _GXmlDomParentNodeIface GXmlDomParentNodeIface;

#define GXML_TYPE_DOM_CHILD_NODE (gxml_dom_child_node_get_type ())
#define GXML_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNode))
#define GXML_IS_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHILD_NODE))
#define GXML_DOM_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNodeIface))

typedef struct _GXmlDomChildNode GXmlDomChildNode;
typedef struct _GXmlDomChildNodeIface GXmlDomChildNodeIface;

#define GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE (gxml_dom_non_document_type_child_node_get_type ())
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNode))
#define GXML_IS_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE))
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNodeIface))

typedef struct _GXmlDomNonDocumentTypeChildNode GXmlDomNonDocumentTypeChildNode;
typedef struct _GXmlDomNonDocumentTypeChildNodeIface GXmlDomNonDocumentTypeChildNodeIface;

#define GXML_TYPE_DOM_ELEMENT (gxml_dom_element_get_type ())
#define GXML_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElement))
#define GXML_IS_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT))
#define GXML_DOM_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElementIface))

typedef struct _GXmlDomElement GXmlDomElement;
typedef struct _GXmlDomElementIface GXmlDomElementIface;

#define GXML_TYPE_DOM_HTML_COLLECTION (gxml_dom_html_collection_get_type ())
#define GXML_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollection))
#define GXML_IS_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_HTML_COLLECTION))
#define GXML_DOM_HTML_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollectionIface))

typedef struct _GXmlDomHTMLCollection GXmlDomHTMLCollection;
typedef struct _GXmlDomHTMLCollectionIface GXmlDomHTMLCollectionIface;

#define GXML_TYPE_DOM_TOKEN_LIST (gxml_dom_token_list_get_type ())
#define GXML_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenList))
#define GXML_IS_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TOKEN_LIST))
#define GXML_DOM_TOKEN_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenListIface))

typedef struct _GXmlDomTokenList GXmlDomTokenList;
typedef struct _GXmlDomTokenListIface GXmlDomTokenListIface;

#define GXML_TYPE_DOM_NAMED_NODE_MAP (gxml_dom_named_node_map_get_type ())
#define GXML_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMap))
#define GXML_IS_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP))
#define GXML_DOM_NAMED_NODE_MAP_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMapIface))

typedef struct _GXmlDomNamedNodeMap GXmlDomNamedNodeMap;
typedef struct _GXmlDomNamedNodeMapIface GXmlDomNamedNodeMapIface;

#define GXML_TYPE_DOM_NODE_LIST (gxml_dom_node_list_get_type ())
#define GXML_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeList))
#define GXML_IS_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_LIST))
#define GXML_DOM_NODE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeListIface))

typedef struct _GXmlDomNodeList GXmlDomNodeList;
typedef struct _GXmlDomNodeListIface GXmlDomNodeListIface;

#define GXML_TYPE_DOM_ELEMENT_LIST (gxml_dom_element_list_get_type ())
#define GXML_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementList))
#define GXML_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))
#define GXML_IS_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_IS_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_DOM_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))

typedef struct _GXmlDomElementList GXmlDomElementList;
typedef struct _GXmlDomElementListClass GXmlDomElementListClass;

#define GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE (gxml_dom_non_element_parent_node_get_type ())
#define GXML_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNode))
#define GXML_IS_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE))
#define GXML_DOM_NON_ELEMENT_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNodeIface))

typedef struct _GXmlDomNonElementParentNode GXmlDomNonElementParentNode;
typedef struct _GXmlDomNonElementParentNodeIface GXmlDomNonElementParentNodeIface;

#define GXML_TYPE_DOM_DOCUMENT (gxml_dom_document_get_type ())
#define GXML_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocument))
#define GXML_IS_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT))
#define GXML_DOM_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocumentIface))

typedef struct _GXmlDomDocument GXmlDomDocument;
typedef struct _GXmlDomDocumentIface GXmlDomDocumentIface;

#define GXML_TYPE_DOM_DOCUMENT_FRAGMENT (gxml_dom_document_fragment_get_type ())
#define GXML_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragment))
#define GXML_IS_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT))
#define GXML_DOM_DOCUMENT_FRAGMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragmentIface))

typedef struct _GXmlDomDocumentFragment GXmlDomDocumentFragment;
typedef struct _GXmlDomDocumentFragmentIface GXmlDomDocumentFragmentIface;

#define GXML_TYPE_DOM_CHARACTER_DATA (gxml_dom_character_data_get_type ())
#define GXML_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterData))
#define GXML_IS_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHARACTER_DATA))
#define GXML_DOM_CHARACTER_DATA_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterDataIface))

typedef struct _GXmlDomCharacterData GXmlDomCharacterData;
typedef struct _GXmlDomCharacterDataIface GXmlDomCharacterDataIface;

#define GXML_TYPE_DOM_TEXT (gxml_dom_text_get_type ())
#define GXML_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TEXT, GXmlDomText))
#define GXML_IS_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TEXT))
#define GXML_DOM_TEXT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TEXT, GXmlDomTextIface))

typedef struct _GXmlDomText GXmlDomText;
typedef struct _GXmlDomTextIface GXmlDomTextIface;

#define GXML_TYPE_DOM_COMMENT (gxml_dom_comment_get_type ())
#define GXML_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomComment))
#define GXML_IS_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_COMMENT))
#define GXML_DOM_COMMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomCommentIface))

typedef struct _GXmlDomComment GXmlDomComment;
typedef struct _GXmlDomCommentIface GXmlDomCommentIface;

#define GXML_TYPE_DOM_PROCESSING_INSTRUCTION (gxml_dom_processing_instruction_get_type ())
#define GXML_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstruction))
#define GXML_IS_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION))
#define GXML_DOM_PROCESSING_INSTRUCTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstructionIface))

typedef struct _GXmlDomProcessingInstruction GXmlDomProcessingInstruction;
typedef struct _GXmlDomProcessingInstructionIface GXmlDomProcessingInstructionIface;

#define GXML_TYPE_DOM_RANGE (gxml_dom_range_get_type ())
#define GXML_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRange))
#define GXML_IS_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_RANGE))
#define GXML_DOM_RANGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRangeIface))

typedef struct _GXmlDomRange GXmlDomRange;
typedef struct _GXmlDomRangeIface GXmlDomRangeIface;

#define GXML_DOM_RANGE_TYPE_BOUNDARY_POINTS (gxml_dom_range_boundary_points_get_type ())

#define GXML_TYPE_DOM_NODE_FILTER (gxml_dom_node_filter_get_type ())
#define GXML_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilter))
#define GXML_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))
#define GXML_IS_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_IS_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_DOM_NODE_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))

typedef struct _GXmlDomNodeFilter GXmlDomNodeFilter;
typedef struct _GXmlDomNodeFilterClass GXmlDomNodeFilterClass;

#define GXML_TYPE_DOM_NODE_ITERATOR (gxml_dom_node_iterator_get_type ())
#define GXML_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIterator))
#define GXML_IS_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_ITERATOR))
#define GXML_DOM_NODE_ITERATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIteratorIface))

typedef struct _GXmlDomNodeIterator GXmlDomNodeIterator;
typedef struct _GXmlDomNodeIteratorIface GXmlDomNodeIteratorIface;

#define GXML_TYPE_DOM_TREE_WALKER (gxml_dom_tree_walker_get_type ())
#define GXML_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalker))
#define GXML_IS_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TREE_WALKER))
#define GXML_DOM_TREE_WALKER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalkerIface))

typedef struct _GXmlDomTreeWalker GXmlDomTreeWalker;
typedef struct _GXmlDomTreeWalkerIface GXmlDomTreeWalkerIface;

#define GXML_TYPE_DOM_IMPLEMENTATION (gxml_dom_implementation_get_type ())
#define GXML_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementation))
#define GXML_IS_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_IMPLEMENTATION))
#define GXML_DOM_IMPLEMENTATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementationIface))

typedef struct _GXmlDomImplementation GXmlDomImplementation;
typedef struct _GXmlDomImplementationIface GXmlDomImplementationIface;

#define GXML_TYPE_DOM_DOCUMENT_TYPE (gxml_dom_document_type_get_type ())
#define GXML_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentType))
#define GXML_IS_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE))
#define GXML_DOM_DOCUMENT_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentTypeIface))

typedef struct _GXmlDomDocumentType GXmlDomDocumentType;
typedef struct _GXmlDomDocumentTypeIface GXmlDomDocumentTypeIface;

#define GXML_TYPE_DOM_XML_DOCUMENT (gxml_dom_xml_document_get_type ())
#define GXML_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocument))
#define GXML_IS_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_XML_DOCUMENT))
#define GXML_DOM_XML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocumentIface))

typedef struct _GXmlDomXMLDocument GXmlDomXMLDocument;
typedef struct _GXmlDomXMLDocumentIface GXmlDomXMLDocumentIface;

#define GXML_TYPE_NODE (gxml_node_get_type ())
#define GXML_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NODE, GXmlNode))
#define GXML_IS_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NODE))
#define GXML_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NODE, GXmlNodeIface))

typedef struct _GXmlNode GXmlNode;
typedef struct _GXmlNodeIface GXmlNodeIface;

#define GXML_TYPE_ELEMENT_LIST (gxml_element_list_get_type ())
#define GXML_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementList))
#define GXML_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))
#define GXML_IS_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT_LIST))
#define GXML_IS_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_ELEMENT_LIST))
#define GXML_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))

typedef struct _GXmlElementList GXmlElementList;
typedef struct _GXmlElementListClass GXmlElementListClass;

#define GXML_TYPE_NAMESPACE (gxml_namespace_get_type ())
#define GXML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE, GXmlNamespace))
#define GXML_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE))
#define GXML_NAMESPACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NAMESPACE, GXmlNamespaceIface))

typedef struct _GXmlNamespace GXmlNamespace;
typedef struct _GXmlNamespaceIface GXmlNamespaceIface;

#define GXML_TYPE_NODE_TYPE (gxml_node_type_get_type ())

#define GXML_TYPE_DOCUMENT (gxml_document_get_type ())
#define GXML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOCUMENT, GXmlDocument))
#define GXML_IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOCUMENT))
#define GXML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOCUMENT, GXmlDocumentIface))

typedef struct _GXmlDocument GXmlDocument;
typedef struct _GXmlDocumentIface GXmlDocumentIface;

#define GXML_TYPE_GOM_NODE (gxml_gom_node_get_type ())
#define GXML_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GOM_NODE, GXmlGomNode))
#define GXML_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))
#define GXML_IS_GOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GOM_NODE))
#define GXML_IS_GOM_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GOM_NODE))
#define GXML_GOM_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GOM_NODE, GXmlGomNodeClass))

typedef struct _GXmlGomNode GXmlGomNode;
typedef struct _GXmlGomNodeClass GXmlGomNodeClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define GXML_TYPE_DOM_ERROR_NAME (gxml_dom_error_name_get_type ())
#define GXML_DOM_ERROR_NAME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ERROR_NAME, GXmlDomErrorName))
#define GXML_DOM_ERROR_NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_ERROR_NAME, GXmlDomErrorNameClass))
#define GXML_IS_DOM_ERROR_NAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ERROR_NAME))
#define GXML_IS_DOM_ERROR_NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_ERROR_NAME))
#define GXML_DOM_ERROR_NAME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_ERROR_NAME, GXmlDomErrorNameClass))

typedef struct _GXmlDomErrorName GXmlDomErrorName;
typedef struct _GXmlDomErrorNameClass GXmlDomErrorNameClass;
typedef struct _GXmlDomErrorNamePrivate GXmlDomErrorNamePrivate;

typedef enum  {
	GXML_DOM_EVENT_PHASE_NONE = 0,
	GXML_DOM_EVENT_PHASE_CAPTURING_PHASE,
	GXML_DOM_EVENT_PHASE_AT_TARGET,
	GXML_DOM_EVENT_PHASE_BUBBLING_PHASE
} GXmlDomEventPhase;

struct _GXmlDomEventIface {
	GTypeInterface parent_iface;
	void (*stop_propagation) (GXmlDomEvent* self);
	void (*stop_immediate_propagation) (GXmlDomEvent* self);
	void (*prevent_default) (GXmlDomEvent* self);
	void (*init_event) (GXmlDomEvent* self, const gchar* type, gboolean bubbles, gboolean cancelable);
	const gchar* (*get_etype) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_event_target) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_current_target) (GXmlDomEvent* self);
	gboolean (*get_bubbles) (GXmlDomEvent* self);
	gboolean (*get_cancelable) (GXmlDomEvent* self);
	gboolean (*get_is_trusted) (GXmlDomEvent* self);
	GXmlDomTimeStamp* (*get_time_stamp) (GXmlDomEvent* self);
	gboolean (*get_default_prevented) (GXmlDomEvent* self);
	GXmlDomEventPhase (*get_event_phase) (GXmlDomEvent* self);
};

struct _GXmlDomEventListenerIface {
	GTypeInterface parent_iface;
	void (*handle_event) (GXmlDomEventListener* self, GXmlDomEvent* event);
};

struct _GXmlDomEventTargetIface {
	GTypeInterface parent_iface;
	void (*add_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	void (*remove_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	gboolean (*dispatch_event) (GXmlDomEventTarget* self, GXmlDomEvent* event, GError** error);
};

typedef enum  {
	GXML_DOM_NODE_DOCUMENT_POSITION_NONE = 1 << 0,
	GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED = 1 << 1,
	GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING = 1 << 2,
	GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING = 1 << 3,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS = 1 << 4,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY = 1 << 5,
	GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC = 1 << 6
} GXmlDomNodeDocumentPosition;

typedef enum  {
	GXML_DOM_NODE_NODE_TYPE_INVALID = 0,
	GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE = 1,
	GXML_DOM_NODE_NODE_TYPE_ATTRIBUTE_NODE,
	GXML_DOM_NODE_NODE_TYPE_TEXT_NODE,
	GXML_DOM_NODE_NODE_TYPE_CDATA_SECTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_REFERENCE_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_NODE,
	GXML_DOM_NODE_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_NOTATION_NODE
} GXmlDomNodeNodeType;

struct _GXmlDomChildNodeIface {
	GTypeInterface parent_iface;
	void (*remove) (GXmlDomChildNode* self);
};

struct _GXmlDomNonDocumentTypeChildNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_previous_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
	GXmlDomElement* (*get_next_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
};

struct _GXmlDomHTMLCollectionIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement** (*to_array) (GXmlDomHTMLCollection* self, int* result_length1);
	GXmlDomElement* (*item) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement* (*named_item) (GXmlDomHTMLCollection* self, const gchar* name);
	gint (*get_length) (GXmlDomHTMLCollection* self);
};

struct _GXmlDomTokenListIface {
	GTypeInterface parent_iface;
	gchar* (*item) (GXmlDomTokenList* self, gint index);
	gboolean (*contains) (GXmlDomTokenList* self, const gchar* token, GError** error);
	void (*add) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1, GError** error);
	void (*remove) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1);
	gboolean (*toggle) (GXmlDomTokenList* self, const gchar* token, gboolean force, gboolean _auto_, GError** error);
	gchar* (*to_string) (GXmlDomTokenList* self);
	gint (*get_length) (GXmlDomTokenList* self);
};

struct _GXmlDomNamedNodeMapIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNamedNodeMap* self, gint index);
	GXmlDomNode* (*get_named_item) (GXmlDomNamedNodeMap* self, const gchar* name);
	GXmlDomNode* (*set_named_item) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*remove_named_item) (GXmlDomNamedNodeMap* self, const gchar* name, GError** error);
	GXmlDomNode* (*remove_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* localName, GError** error);
	GXmlDomNode* (*get_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* local_name, GError** error);
	GXmlDomNode* (*set_named_item_ns) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	gint (*get_length) (GXmlDomNamedNodeMap* self);
};

struct _GXmlDomElementIface {
	GTypeInterface parent_iface;
	gchar* (*get_attribute) (GXmlDomElement* self, const gchar* name);
	gchar* (*get_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	void (*set_attribute) (GXmlDomElement* self, const gchar* name, const gchar* value, GError** error);
	void (*set_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* name, const gchar* value, GError** error);
	void (*remove_attribute) (GXmlDomElement* self, const gchar* name);
	void (*remove_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	gboolean (*has_attribute) (GXmlDomElement* self, const gchar* name);
	gboolean (*has_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomElement* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomElement* self, const gchar* class_names);
	gchar* (*get_namespace_uri) (GXmlDomElement* self);
	gchar* (*get_prefix) (GXmlDomElement* self);
	gchar* (*get_local_name) (GXmlDomElement* self);
	gchar* (*get_tag_name) (GXmlDomElement* self);
	gchar* (*get_id) (GXmlDomElement* self);
	void (*set_id) (GXmlDomElement* self, const gchar* value);
	gchar* (*get_class_name) (GXmlDomElement* self);
	void (*set_class_name) (GXmlDomElement* self, const gchar* value);
	GXmlDomTokenList* (*get_class_list) (GXmlDomElement* self);
	GXmlDomNamedNodeMap* (*get_attributes) (GXmlDomElement* self);
};

struct _GXmlDomNodeListIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNodeList* self, gint index);
	gint (*get_length) (GXmlDomNodeList* self);
};

struct _GXmlDomParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*query_selector) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomNodeList* (*query_selector_all) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomElementList* (*get_elements_by_property_value) (GXmlDomParentNode* self, const gchar* property, const gchar* value);
	GXmlDomHTMLCollection* (*get_children) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_first_element_child) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_last_element_child) (GXmlDomParentNode* self);
	gint (*get_child_element_count) (GXmlDomParentNode* self);
};

struct _GXmlDomNonElementParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element_by_id) (GXmlDomNonElementParentNode* self, const gchar* element_id, GError** error);
};

struct _GXmlDomDocumentFragmentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomCharacterDataIface {
	GTypeInterface parent_iface;
	gchar* (*substring_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*append_data) (GXmlDomCharacterData* self, const gchar* data);
	void (*insert_data) (GXmlDomCharacterData* self, gint offset, const gchar* data, GError** error);
	void (*delete_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*replace_data) (GXmlDomCharacterData* self, gint offset, gint count, const gchar* data, GError** error);
	gchar* (*get_data) (GXmlDomCharacterData* self);
	void (*set_data) (GXmlDomCharacterData* self, const gchar* value);
	gint (*get_length) (GXmlDomCharacterData* self);
};

struct _GXmlDomTextIface {
	GTypeInterface parent_iface;
	GXmlDomText* (*split_text) (GXmlDomText* self, gint offset, GError** error);
	gchar* (*get_whole_text) (GXmlDomText* self);
};

struct _GXmlDomCommentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomProcessingInstructionIface {
	GTypeInterface parent_iface;
	gchar* (*get_target) (GXmlDomProcessingInstruction* self);
};

typedef enum  {
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_START = 0,
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_START
} GXmlDomRangeBoundaryPoints;

struct _GXmlDomRangeIface {
	GTypeInterface parent_iface;
	void (*set_start) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_end) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_start_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_start_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*collapse) (GXmlDomRange* self, gboolean to_start, GError** error);
	void (*select_node) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*select_node_contents) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	gint (*compare_boundary_points) (GXmlDomRange* self, GXmlDomRangeBoundaryPoints how, GXmlDomRange* sourceRange, GError** error);
	void (*delete_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*extract_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*clone_contents) (GXmlDomRange* self, GError** error);
	void (*insert_node) (GXmlDomRange* self, GXmlDomNode* node);
	void (*surround_contents) (GXmlDomRange* self, GXmlDomNode* newParent);
	GXmlDomRange* (*clone_range) (GXmlDomRange* self);
	void (*detach) (GXmlDomRange* self);
	gboolean (*is_point_in_range) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gshort (*compare_point) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gboolean (*intersects_node) (GXmlDomRange* self, GXmlDomNode* node);
	gchar* (*to_string) (GXmlDomRange* self);
	GXmlDomNode* (*get_start_container) (GXmlDomRange* self);
	gint (*get_start_offset) (GXmlDomRange* self);
	GXmlDomNode* (*get_end_container) (GXmlDomRange* self);
	gint (*get_end_offset) (GXmlDomRange* self);
	gboolean (*get_collapsed) (GXmlDomRange* self);
	GXmlDomNode* (*get_common_ancestor_container) (GXmlDomRange* self);
};

struct _GXmlDomNodeIteratorIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*next_node) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*previous_node) (GXmlDomNodeIterator* self);
	void (*detach) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_root) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_reference_node) (GXmlDomNodeIterator* self);
	gboolean (*get_pointer_before_reference_node) (GXmlDomNodeIterator* self);
	gint (*get_what_to_show) (GXmlDomNodeIterator* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomNodeIterator* self);
};

struct _GXmlDomTreeWalkerIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*parentNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*firstChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*lastChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_root) (GXmlDomTreeWalker* self);
	gint (*get_what_to_show) (GXmlDomTreeWalker* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_current_node) (GXmlDomTreeWalker* self);
};

struct _GXmlDomDocumentTypeIface {
	GTypeInterface parent_iface;
	const gchar* (*get_name) (GXmlDomDocumentType* self);
	const gchar* (*get_public_id) (GXmlDomDocumentType* self);
	const gchar* (*get_system_id) (GXmlDomDocumentType* self);
};

struct _GXmlDomXMLDocumentIface {
	GTypeInterface parent_iface;
};

struct _GXmlNamespaceIface {
	GTypeInterface parent_iface;
	gchar* (*get_uri) (GXmlNamespace* self);
	gchar* (*get_prefix) (GXmlNamespace* self);
};

typedef enum  {
	GXML_NODE_TYPE_INVALID = 0,
	GXML_NODE_TYPE_ELEMENT = 1,
	GXML_NODE_TYPE_ATTRIBUTE,
	GXML_NODE_TYPE_TEXT,
	GXML_NODE_TYPE_CDATA_SECTION,
	GXML_NODE_TYPE_ENTITY_REFERENCE,
	GXML_NODE_TYPE_ENTITY,
	GXML_NODE_TYPE_PROCESSING_INSTRUCTION,
	GXML_NODE_TYPE_COMMENT,
	GXML_NODE_TYPE_DOCUMENT,
	GXML_NODE_TYPE_DOCUMENT_TYPE,
	GXML_NODE_TYPE_DOCUMENT_FRAGMENT,
	GXML_NODE_TYPE_NOTATION
} GXmlNodeType;

struct _GXmlNodeIface {
	GTypeInterface parent_iface;
	GXmlNode* (*get) (GXmlNode* self, const gchar* key);
	GXmlElementList* (*get_elements_by_property_value) (GXmlNode* self, const gchar* property, const gchar* value);
	GXmlElementList* (*get_elements_by_name) (GXmlNode* self, const gchar* name);
	GXmlElementList* (*get_elements_by_name_ns) (GXmlNode* self, const gchar* name, const gchar* ns);
	gchar* (*to_string) (GXmlNode* self);
	gboolean (*set_namespace) (GXmlNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*ns_prefix) (GXmlNode* self);
	gchar* (*ns_uri) (GXmlNode* self);
	GeeList* (*get_namespaces) (GXmlNode* self);
	GeeBidirList* (*get_children_nodes) (GXmlNode* self);
	GeeMap* (*get_attrs) (GXmlNode* self);
	gchar* (*get_name) (GXmlNode* self);
	gchar* (*get_value) (GXmlNode* self);
	void (*set_value) (GXmlNode* self, const gchar* value);
	GXmlNodeType (*get_type_node) (GXmlNode* self);
	GXmlDocument* (*get_document) (GXmlNode* self);
	GXmlNode* (*get_parent) (GXmlNode* self);
};

struct _GXmlDocumentIface {
	GTypeInterface parent_iface;
	GXmlNode* (*create_element) (GXmlDocument* self, const gchar* name, GError** error);
	GXmlNode* (*create_text) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_comment) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_cdata) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_pi) (GXmlDocument* self, const gchar* target, const gchar* data);
	gboolean (*save) (GXmlDocument* self, GCancellable* cancellable, GError** error);
	gboolean (*save_as) (GXmlDocument* self, GFile* f, GCancellable* cancellable, GError** error);
	gboolean (*get_indent) (GXmlDocument* self);
	void (*set_indent) (GXmlDocument* self, gboolean value);
	gboolean (*get_ns_top) (GXmlDocument* self);
	void (*set_ns_top) (GXmlDocument* self, gboolean value);
	gboolean (*get_prefix_default_ns) (GXmlDocument* self);
	void (*set_prefix_default_ns) (GXmlDocument* self, gboolean value);
	gboolean (*get_backup) (GXmlDocument* self);
	void (*set_backup) (GXmlDocument* self, gboolean value);
	GXmlNode* (*get_root) (GXmlDocument* self);
	GFile* (*get_file) (GXmlDocument* self);
	void (*set_file) (GXmlDocument* self, GFile* value);
};

struct _GXmlDomImplementationIface {
	GTypeInterface parent_iface;
	GXmlDomDocumentType* (*create_document_type) (GXmlDomImplementation* self, const gchar* qualified_name, const gchar* public_id, const gchar* system_id, GError** error);
	GXmlDomXMLDocument* (*create_document) (GXmlDomImplementation* self, const gchar* nspace, const gchar* qualified_name, GXmlDomDocumentType* doctype, GError** error);
	GXmlDocument* (*create_html_document) (GXmlDomImplementation* self, const gchar* title);
	gboolean (*has_feature) (GXmlDomImplementation* self);
};

struct _GXmlDomDocumentIface {
	GTypeInterface parent_iface;
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomDocument* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomDocument* self, const gchar* classNames);
	GXmlDomElement* (*create_element) (GXmlDomDocument* self, const gchar* local_name, GError** error);
	GXmlDomElement* (*create_element_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* qualified_name, GError** error);
	GXmlDomDocumentFragment* (*create_document_fragment) (GXmlDomDocument* self);
	GXmlDomText* (*create_text_node) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomComment* (*create_comment) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomProcessingInstruction* (*create_processing_instruction) (GXmlDomDocument* self, const gchar* target, const gchar* data, GError** error);
	GXmlDomNode* (*import_node) (GXmlDomDocument* self, GXmlDomNode* node, gboolean deep, GError** error);
	GXmlDomNode* (*adopt_node) (GXmlDomDocument* self, GXmlDomNode* node, GError** error);
	GXmlDomEvent* (*create_event) (GXmlDomDocument* self, const gchar* interface, GError** error);
	GXmlDomRange* (*create_range) (GXmlDomDocument* self);
	GXmlDomNodeIterator* (*create_node_iterator) (GXmlDomDocument* self, GXmlDomNode* root, gint whatToShow, GXmlDomNodeFilter* filter);
	GXmlDomTreeWalker* (*create_tree_walker) (GXmlDomDocument* self, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter);
	GXmlDomImplementation* (*get_implementation) (GXmlDomDocument* self);
	const gchar* (*get_url) (GXmlDomDocument* self);
	const gchar* (*get_document_uri) (GXmlDomDocument* self);
	const gchar* (*get_origin) (GXmlDomDocument* self);
	const gchar* (*get_compat_mode) (GXmlDomDocument* self);
	const gchar* (*get_character_set) (GXmlDomDocument* self);
	const gchar* (*get_content_type) (GXmlDomDocument* self);
	GXmlDomDocumentType* (*get_doctype) (GXmlDomDocument* self);
	GXmlDomElement* (*get_document_element) (GXmlDomDocument* self);
};

struct _GXmlDomNodeIface {
	GTypeInterface parent_iface;
	gboolean (*has_child_nodes) (GXmlDomNode* self);
	void (*normalize) (GXmlDomNode* self);
	gboolean (*is_equal_node) (GXmlDomNode* self, GXmlDomNode* node);
	GXmlDomNodeDocumentPosition (*compare_document_position) (GXmlDomNode* self, GXmlDomNode* other);
	gboolean (*contains) (GXmlDomNode* self, GXmlDomNode* other);
	gchar* (*lookup_prefix) (GXmlDomNode* self, const gchar* nspace);
	gchar* (*lookup_namespace_uri) (GXmlDomNode* self, const gchar* prefix);
	gboolean (*is_default_namespace) (GXmlDomNode* self, const gchar* nspace);
	GXmlDomNode* (*insert_before) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*append_child) (GXmlDomNode* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*replace_child) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*remove_child) (GXmlDomNode* self, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*clone_node) (GXmlDomNode* self, gboolean deep, GError** error);
	GXmlDomNodeNodeType (*get_node_type) (GXmlDomNode* self);
	gchar* (*get_node_name) (GXmlDomNode* self);
	const gchar* (*get_base_uri) (GXmlDomNode* self);
	GXmlDomDocument* (*get_owner_document) (GXmlDomNode* self);
	void (*set_owner_document) (GXmlDomNode* self, GXmlDomDocument* value);
	GXmlDomNode* (*get_parent_node) (GXmlDomNode* self);
	GXmlDomElement* (*get_parent_element) (GXmlDomNode* self);
	GXmlDomNodeList* (*get_child_nodes) (GXmlDomNode* self);
	GXmlDomNode* (*get_first_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_last_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_previous_sibling) (GXmlDomNode* self);
	GXmlDomNode* (*get_next_sibling) (GXmlDomNode* self);
	gchar* (*get_node_value) (GXmlDomNode* self);
	void (*set_node_value) (GXmlDomNode* self, const gchar* value);
	gchar* (*get_text_content) (GXmlDomNode* self);
	void (*set_text_content) (GXmlDomNode* self, const gchar* value);
};

/**
 * DOM4 error codes.
 */
typedef enum  {
	GXML_DOM_ERROR_INDEX_SIZE_ERROR = 1,
	GXML_DOM_ERROR_DOMSTRING_SIZE_ERROR,
	GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR,
	GXML_DOM_ERROR_WRONG_DOCUMENT_ERROR,
	GXML_DOM_ERROR_INVALID_CHARACTER_ERROR,
	GXML_DOM_ERROR_NO_DATA_ALLOWED_ERROR,
	GXML_DOM_ERROR_NO_MODIFICATION_ALLOWED_ERROR,
	GXML_DOM_ERROR_NOT_FOUND_ERROR,
	GXML_DOM_ERROR_NOT_SUPPORTED_ERROR,
	GXML_DOM_ERROR_INUSE_ATTRIBUTE_ERROR,
	GXML_DOM_ERROR_INVALID_STATE_ERROR,
	GXML_DOM_ERROR_SYNTAX_ERROR,
	GXML_DOM_ERROR_INVALID_MODIFICATION_ERROR,
	GXML_DOM_ERROR_NAMESPACE_ERROR,
	GXML_DOM_ERROR_INVALID_ACCESS_ERROR,
	GXML_DOM_ERROR_VALIDATION_ERROR,
	GXML_DOM_ERROR_TYPE_MISMATCH_ERROR,
	GXML_DOM_ERROR_SECURITY_ERROR,
	GXML_DOM_ERROR_NETWORK_ERROR,
	GXML_DOM_ERROR_ABORT_ERROR,
	GXML_DOM_ERROR_URL_MISMATCH_ERROR,
	GXML_DOM_ERROR_QUOTA_EXCEEDED_ERROR,
	GXML_DOM_ERROR_TIME_OUT_ERROR,
	GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR,
	GXML_DOM_ERROR_DATA_CLONE_ERROR
} GXmlDomError;
#define GXML_DOM_ERROR gxml_dom_error_quark ()
struct _GXmlDomErrorName {
	GObject parent_instance;
	GXmlDomErrorNamePrivate * priv;
};

struct _GXmlDomErrorNameClass {
	GObjectClass parent_class;
};

struct _GXmlDomErrorNamePrivate {
	GeeHashMap* names;
};


static gpointer gxml_dom_error_name_parent_class = NULL;

GType gxml_dom_time_stamp_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_phase_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_listener_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_target_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_document_position_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_node_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_document_type_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_html_collection_get_type (void) G_GNUC_CONST;
GType gxml_dom_token_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_named_node_map_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_element_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_fragment_get_type (void) G_GNUC_CONST;
GType gxml_dom_character_data_get_type (void) G_GNUC_CONST;
GType gxml_dom_text_get_type (void) G_GNUC_CONST;
GType gxml_dom_comment_get_type (void) G_GNUC_CONST;
GType gxml_dom_processing_instruction_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_boundary_points_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_filter_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_iterator_get_type (void) G_GNUC_CONST;
GType gxml_dom_tree_walker_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_xml_document_get_type (void) G_GNUC_CONST;
GType gxml_element_list_get_type (void) G_GNUC_CONST;
GType gxml_namespace_get_type (void) G_GNUC_CONST;
GType gxml_node_type_get_type (void) G_GNUC_CONST;
GType gxml_node_get_type (void) G_GNUC_CONST;
GType gxml_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_implementation_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_get_type (void) G_GNUC_CONST;
gboolean gxml_dom_node_has_child_nodes (GXmlDomNode* self);
void gxml_dom_node_normalize (GXmlDomNode* self);
gboolean gxml_dom_node_is_equal_node (GXmlDomNode* self, GXmlDomNode* node);
GXmlDomNodeDocumentPosition gxml_dom_node_compare_document_position (GXmlDomNode* self, GXmlDomNode* other);
gboolean gxml_dom_node_contains (GXmlDomNode* self, GXmlDomNode* other);
gchar* gxml_dom_node_lookup_prefix (GXmlDomNode* self, const gchar* nspace);
gchar* gxml_dom_node_lookup_namespace_uri (GXmlDomNode* self, const gchar* prefix);
gboolean gxml_dom_node_is_default_namespace (GXmlDomNode* self, const gchar* nspace);
GXmlDomNode* gxml_dom_node_insert_before (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
GXmlDomNode* gxml_dom_node_append_child (GXmlDomNode* self, GXmlDomNode* node, GError** error);
GXmlDomNode* gxml_dom_node_replace_child (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
GXmlDomNode* gxml_dom_node_remove_child (GXmlDomNode* self, GXmlDomNode* child, GError** error);
GXmlDomNode* gxml_dom_node_clone_node (GXmlDomNode* self, gboolean deep, GError** error);
static GXmlDomNode* gxml_dom_node_real_clone_node (GXmlDomNode* self, gboolean deep, GError** error);
GXmlGomNode* gxml_gom_node_new (void);
GXmlGomNode* gxml_gom_node_construct (GType object_type);
GType gxml_gom_node_get_type (void) G_GNUC_CONST;
GXmlDomDocument* gxml_dom_node_get_owner_document (GXmlDomNode* self);
GXmlDomNodeNodeType gxml_dom_node_get_node_type (GXmlDomNode* self);
GXmlDomElement* gxml_dom_document_create_element (GXmlDomDocument* self, const gchar* local_name, GError** error);
gchar* gxml_dom_node_get_node_name (GXmlDomNode* self);
gboolean gxml_dom_node_copy (GXmlDomDocument* doc, GXmlDomNode* node, GXmlDomNode* source, gboolean deep, GError** error);
GXmlDomComment* gxml_dom_document_create_comment (GXmlDomDocument* self, const gchar* data, GError** error);
gchar* gxml_dom_character_data_get_data (GXmlDomCharacterData* self);
GXmlDomText* gxml_dom_document_create_text_node (GXmlDomDocument* self, const gchar* data, GError** error);
GXmlDomNamedNodeMap* gxml_dom_element_get_attributes (GXmlDomElement* self);
void gxml_dom_element_set_attribute (GXmlDomElement* self, const gchar* name, const gchar* value, GError** error);
gchar* gxml_dom_node_get_node_value (GXmlDomNode* self);
GXmlDomNodeList* gxml_dom_node_get_child_nodes (GXmlDomNode* self);
const gchar* gxml_dom_node_get_base_uri (GXmlDomNode* self);
void gxml_dom_node_set_owner_document (GXmlDomNode* self, GXmlDomDocument* value);
GXmlDomNode* gxml_dom_node_get_parent_node (GXmlDomNode* self);
GXmlDomElement* gxml_dom_node_get_parent_element (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_first_child (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_last_child (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_previous_sibling (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_next_sibling (GXmlDomNode* self);
void gxml_dom_node_set_node_value (GXmlDomNode* self, const gchar* value);
gchar* gxml_dom_node_get_text_content (GXmlDomNode* self);
void gxml_dom_node_set_text_content (GXmlDomNode* self, const gchar* value);
GQuark gxml_dom_error_quark (void);
GType gxml_dom_error_name_get_type (void) G_GNUC_CONST;
#define GXML_DOM_ERROR_NAME_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GXML_TYPE_DOM_ERROR_NAME, GXmlDomErrorNamePrivate))
enum  {
	GXML_DOM_ERROR_NAME_0_PROPERTY
};
gchar* gxml_dom_error_name_get_name (GXmlDomErrorName* self, gint error_code);
gint gxml_dom_error_name_get_code (GXmlDomErrorName* self, const gchar* error_name);
GXmlDomErrorName* gxml_dom_error_name_new (void);
GXmlDomErrorName* gxml_dom_error_name_construct (GType object_type);
static GObject * gxml_dom_error_name_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gxml_dom_error_name_finalize (GObject* obj);


GType gxml_dom_node_node_type_get_type (void) {
	static volatile gsize gxml_dom_node_node_type_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_dom_node_node_type_type_id__volatile)) {
		static const GEnumValue values[] = {{GXML_DOM_NODE_NODE_TYPE_INVALID, "GXML_DOM_NODE_NODE_TYPE_INVALID", "invalid"}, {GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE, "GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE", "element-node"}, {GXML_DOM_NODE_NODE_TYPE_ATTRIBUTE_NODE, "GXML_DOM_NODE_NODE_TYPE_ATTRIBUTE_NODE", "attribute-node"}, {GXML_DOM_NODE_NODE_TYPE_TEXT_NODE, "GXML_DOM_NODE_NODE_TYPE_TEXT_NODE", "text-node"}, {GXML_DOM_NODE_NODE_TYPE_CDATA_SECTION_NODE, "GXML_DOM_NODE_NODE_TYPE_CDATA_SECTION_NODE", "cdata-section-node"}, {GXML_DOM_NODE_NODE_TYPE_ENTITY_REFERENCE_NODE, "GXML_DOM_NODE_NODE_TYPE_ENTITY_REFERENCE_NODE", "entity-reference-node"}, {GXML_DOM_NODE_NODE_TYPE_ENTITY_NODE, "GXML_DOM_NODE_NODE_TYPE_ENTITY_NODE", "entity-node"}, {GXML_DOM_NODE_NODE_TYPE_PROCESSING_INSTRUCTION_NODE, "GXML_DOM_NODE_NODE_TYPE_PROCESSING_INSTRUCTION_NODE", "processing-instruction-node"}, {GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE, "GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE", "comment-node"}, {GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE, "GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE", "document-node"}, {GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE, "GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE", "document-type-node"}, {GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE, "GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE", "document-fragment-node"}, {GXML_DOM_NODE_NODE_TYPE_NOTATION_NODE, "GXML_DOM_NODE_NODE_TYPE_NOTATION_NODE", "notation-node"}, {0, NULL, NULL}};
		GType gxml_dom_node_node_type_type_id;
		gxml_dom_node_node_type_type_id = g_enum_register_static ("GXmlDomNodeNodeType", values);
		g_once_init_leave (&gxml_dom_node_node_type_type_id__volatile, gxml_dom_node_node_type_type_id);
	}
	return gxml_dom_node_node_type_type_id__volatile;
}


GType gxml_dom_node_document_position_get_type (void) {
	static volatile gsize gxml_dom_node_document_position_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_dom_node_document_position_type_id__volatile)) {
		static const GFlagsValue values[] = {{GXML_DOM_NODE_DOCUMENT_POSITION_NONE, "GXML_DOM_NODE_DOCUMENT_POSITION_NONE", "none"}, {GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED, "GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED", "disconnected"}, {GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING, "GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING", "preceding"}, {GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING, "GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING", "following"}, {GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS, "GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS", "contains"}, {GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY, "GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY", "contained-by"}, {GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC, "GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC", "implementation-specific"}, {0, NULL, NULL}};
		GType gxml_dom_node_document_position_type_id;
		gxml_dom_node_document_position_type_id = g_flags_register_static ("GXmlDomNodeDocumentPosition", values);
		g_once_init_leave (&gxml_dom_node_document_position_type_id__volatile, gxml_dom_node_document_position_type_id);
	}
	return gxml_dom_node_document_position_type_id__volatile;
}


gboolean gxml_dom_node_has_child_nodes (GXmlDomNode* self) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_DOM_NODE_GET_INTERFACE (self)->has_child_nodes (self);
}


void gxml_dom_node_normalize (GXmlDomNode* self) {
	g_return_if_fail (self != NULL);
	GXML_DOM_NODE_GET_INTERFACE (self)->normalize (self);
}


gboolean gxml_dom_node_is_equal_node (GXmlDomNode* self, GXmlDomNode* node) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_DOM_NODE_GET_INTERFACE (self)->is_equal_node (self, node);
}


GXmlDomNodeDocumentPosition gxml_dom_node_compare_document_position (GXmlDomNode* self, GXmlDomNode* other) {
	g_return_val_if_fail (self != NULL, 0);
	return GXML_DOM_NODE_GET_INTERFACE (self)->compare_document_position (self, other);
}


gboolean gxml_dom_node_contains (GXmlDomNode* self, GXmlDomNode* other) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_DOM_NODE_GET_INTERFACE (self)->contains (self, other);
}


gchar* gxml_dom_node_lookup_prefix (GXmlDomNode* self, const gchar* nspace) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_DOM_NODE_GET_INTERFACE (self)->lookup_prefix (self, nspace);
}


gchar* gxml_dom_node_lookup_namespace_uri (GXmlDomNode* self, const gchar* prefix) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_DOM_NODE_GET_INTERFACE (self)->lookup_namespace_uri (self, prefix);
}


gboolean gxml_dom_node_is_default_namespace (GXmlDomNode* self, const gchar* nspace) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_DOM_NODE_GET_INTERFACE (self)->is_default_namespace (self, nspace);
}


GXmlDomNode* gxml_dom_node_insert_before (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_DOM_NODE_GET_INTERFACE (self)->insert_before (self, node, child, error);
}


GXmlDomNode* gxml_dom_node_append_child (GXmlDomNode* self, GXmlDomNode* node, GError** error) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_DOM_NODE_GET_INTERFACE (self)->append_child (self, node, error);
}


GXmlDomNode* gxml_dom_node_replace_child (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_DOM_NODE_GET_INTERFACE (self)->replace_child (self, node, child, error);
}


GXmlDomNode* gxml_dom_node_remove_child (GXmlDomNode* self, GXmlDomNode* child, GError** error) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_DOM_NODE_GET_INTERFACE (self)->remove_child (self, child, error);
}


static GXmlDomNode* gxml_dom_node_real_clone_node (GXmlDomNode* self, gboolean deep, GError** error) {
	GXmlDomNode* result = NULL;
	GXmlDomNode* n = NULL;
	GXmlGomNode* _tmp0_ = NULL;
	GXmlDomDocument* _tmp1_ = NULL;
	GXmlDomDocument* _tmp2_ = NULL;
	GXmlDomNodeNodeType _tmp4_ = 0;
	GXmlDomNodeNodeType _tmp5_ = 0;
	GError * _inner_error_ = NULL;
	_tmp0_ = gxml_gom_node_new ();
	n = (GXmlDomNode*) _tmp0_;
	_tmp1_ = gxml_dom_node_get_owner_document (self);
	_tmp2_ = _tmp1_;
	if (_tmp2_ == NULL) {
		GXmlGomNode* _tmp3_ = NULL;
		_tmp3_ = gxml_gom_node_new ();
		result = (GXmlDomNode*) _tmp3_;
		_g_object_unref0 (n);
		return result;
	}
	_tmp4_ = gxml_dom_node_get_node_type (self);
	_tmp5_ = _tmp4_;
	switch (_tmp5_) {
		case GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE:
		{
			GXmlDomElement* _tmp6_ = NULL;
			GXmlDomDocument* _tmp7_ = NULL;
			GXmlDomDocument* _tmp8_ = NULL;
			gchar* _tmp9_ = NULL;
			gchar* _tmp10_ = NULL;
			gchar* _tmp11_ = NULL;
			GXmlDomElement* _tmp12_ = NULL;
			GXmlDomElement* _tmp13_ = NULL;
			GXmlDomElement* _tmp14_ = NULL;
			GXmlDomDocument* _tmp15_ = NULL;
			GXmlDomDocument* _tmp16_ = NULL;
			GXmlDomNode* _tmp17_ = NULL;
			_tmp7_ = gxml_dom_node_get_owner_document (self);
			_tmp8_ = _tmp7_;
			_tmp9_ = gxml_dom_node_get_node_name (self);
			_tmp10_ = _tmp9_;
			_tmp11_ = _tmp10_;
			_tmp12_ = gxml_dom_document_create_element (_tmp8_, _tmp11_, &_inner_error_);
			_tmp13_ = _tmp12_;
			_g_free0 (_tmp11_);
			_tmp6_ = _tmp13_;
			if (G_UNLIKELY (_inner_error_ != NULL)) {
				g_propagate_error (error, _inner_error_);
				_g_object_unref0 (n);
				return NULL;
			}
			_tmp14_ = _tmp6_;
			_tmp6_ = NULL;
			_g_object_unref0 (n);
			n = (GXmlDomNode*) _tmp14_;
			_tmp15_ = gxml_dom_node_get_owner_document (self);
			_tmp16_ = _tmp15_;
			_tmp17_ = n;
			gxml_dom_node_copy (_tmp16_, _tmp17_, self, TRUE, &_inner_error_);
			if (G_UNLIKELY (_inner_error_ != NULL)) {
				g_propagate_error (error, _inner_error_);
				_g_object_unref0 (_tmp6_);
				_g_object_unref0 (n);
				return NULL;
			}
			_g_object_unref0 (_tmp6_);
			break;
		}
		case GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE:
		{
			GXmlDomComment* _tmp18_ = NULL;
			GXmlDomDocument* _tmp19_ = NULL;
			GXmlDomDocument* _tmp20_ = NULL;
			gchar* _tmp21_ = NULL;
			gchar* _tmp22_ = NULL;
			gchar* _tmp23_ = NULL;
			GXmlDomComment* _tmp24_ = NULL;
			GXmlDomComment* _tmp25_ = NULL;
			GXmlDomComment* _tmp26_ = NULL;
			_tmp19_ = gxml_dom_node_get_owner_document (self);
			_tmp20_ = _tmp19_;
			_tmp21_ = gxml_dom_character_data_get_data ((GXmlDomCharacterData*) (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_COMMENT) ? ((GXmlDomComment*) self) : NULL));
			_tmp22_ = _tmp21_;
			_tmp23_ = _tmp22_;
			_tmp24_ = gxml_dom_document_create_comment (_tmp20_, _tmp23_, &_inner_error_);
			_tmp25_ = _tmp24_;
			_g_free0 (_tmp23_);
			_tmp18_ = _tmp25_;
			if (G_UNLIKELY (_inner_error_ != NULL)) {
				g_propagate_error (error, _inner_error_);
				_g_object_unref0 (n);
				return NULL;
			}
			_tmp26_ = _tmp18_;
			_tmp18_ = NULL;
			_g_object_unref0 (n);
			n = (GXmlDomNode*) _tmp26_;
			_g_object_unref0 (_tmp18_);
			break;
		}
		case GXML_DOM_NODE_NODE_TYPE_TEXT_NODE:
		{
			GXmlDomText* _tmp27_ = NULL;
			GXmlDomDocument* _tmp28_ = NULL;
			GXmlDomDocument* _tmp29_ = NULL;
			gchar* _tmp30_ = NULL;
			gchar* _tmp31_ = NULL;
			gchar* _tmp32_ = NULL;
			GXmlDomText* _tmp33_ = NULL;
			GXmlDomText* _tmp34_ = NULL;
			GXmlDomText* _tmp35_ = NULL;
			_tmp28_ = gxml_dom_node_get_owner_document (self);
			_tmp29_ = _tmp28_;
			_tmp30_ = gxml_dom_character_data_get_data ((GXmlDomCharacterData*) (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_TEXT) ? ((GXmlDomText*) self) : NULL));
			_tmp31_ = _tmp30_;
			_tmp32_ = _tmp31_;
			_tmp33_ = gxml_dom_document_create_text_node (_tmp29_, _tmp32_, &_inner_error_);
			_tmp34_ = _tmp33_;
			_g_free0 (_tmp32_);
			_tmp27_ = _tmp34_;
			if (G_UNLIKELY (_inner_error_ != NULL)) {
				g_propagate_error (error, _inner_error_);
				_g_object_unref0 (n);
				return NULL;
			}
			_tmp35_ = _tmp27_;
			_tmp27_ = NULL;
			_g_object_unref0 (n);
			n = (GXmlDomNode*) _tmp35_;
			_g_object_unref0 (_tmp27_);
			break;
		}
		default:
		break;
	}
	result = n;
	return result;
}


GXmlDomNode* gxml_dom_node_clone_node (GXmlDomNode* self, gboolean deep, GError** error) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_DOM_NODE_GET_INTERFACE (self)->clone_node (self, deep, error);
}


/**
   * Copy a {@link GXml.DomNode} relaying on {@link GXml.DomDocument} to other {@link GXml.DomNode}.
   *
   * {@link node} could belongs from different {@link GXml.DomDocument}, while source is a node
   * belonging to given document.
   *
   * Only {@link GXml.DomElement} objects are supported. For attributes, use
   * {@link GXml.DomElement.set_attribute} method, passing source's name and value as arguments.
   *
   * @param doc a {@link GXml.DomDocument} owning destiny node
   * @param node a {@link GXml.DomElement} to copy nodes to
   * @param source a {@link GXml.DomElement} to copy nodes from, it could be holded by different {@link GXml.DomDocument}
   */
gboolean gxml_dom_node_copy (GXmlDomDocument* doc, GXmlDomNode* node, GXmlDomNode* source, gboolean deep, GError** error) {
	gboolean result = FALSE;
	GXmlDomNode* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	GXmlDomNode* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
	g_return_val_if_fail (doc != NULL, FALSE);
	g_return_val_if_fail (node != NULL, FALSE);
	g_return_val_if_fail (source != NULL, FALSE);
	_tmp0_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT)) {
		result = FALSE;
		return result;
	}
	_tmp2_ = source;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GXML_TYPE_DOM_ELEMENT)) {
		GXmlDomNode* _tmp3_ = NULL;
		_tmp3_ = node;
		_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_DOM_ELEMENT);
	} else {
		_tmp1_ = FALSE;
	}
	if (_tmp1_) {
		gboolean _tmp27_ = FALSE;
		{
			GeeIterator* _p_it = NULL;
			GXmlDomNode* _tmp4_ = NULL;
			GXmlDomNamedNodeMap* _tmp5_ = NULL;
			GXmlDomNamedNodeMap* _tmp6_ = NULL;
			GXmlDomNamedNodeMap* _tmp7_ = NULL;
			GeeCollection* _tmp8_ = NULL;
			GeeCollection* _tmp9_ = NULL;
			GeeCollection* _tmp10_ = NULL;
			GeeIterator* _tmp11_ = NULL;
			GeeIterator* _tmp12_ = NULL;
			_tmp4_ = source;
			_tmp5_ = gxml_dom_element_get_attributes (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp4_) : NULL);
			_tmp6_ = _tmp5_;
			_tmp7_ = _tmp6_;
			_tmp8_ = gee_map_get_values ((GeeMap*) _tmp7_);
			_tmp9_ = _tmp8_;
			_tmp10_ = _tmp9_;
			_tmp11_ = gee_iterable_iterator ((GeeIterable*) _tmp10_);
			_tmp12_ = _tmp11_;
			_g_object_unref0 (_tmp10_);
			_g_object_unref0 (_tmp7_);
			_p_it = _tmp12_;
			while (TRUE) {
				GeeIterator* _tmp13_ = NULL;
				gboolean _tmp14_ = FALSE;
				GXmlDomNode* p = NULL;
				GeeIterator* _tmp15_ = NULL;
				gpointer _tmp16_ = NULL;
				GXmlDomNode* _tmp17_ = NULL;
				GXmlDomNode* _tmp18_ = NULL;
				gchar* _tmp19_ = NULL;
				gchar* _tmp20_ = NULL;
				gchar* _tmp21_ = NULL;
				GXmlDomNode* _tmp22_ = NULL;
				gchar* _tmp23_ = NULL;
				gchar* _tmp24_ = NULL;
				gchar* _tmp25_ = NULL;
				_tmp13_ = _p_it;
				_tmp14_ = gee_iterator_next (_tmp13_);
				if (!_tmp14_) {
					break;
				}
				_tmp15_ = _p_it;
				_tmp16_ = gee_iterator_get (_tmp15_);
				p = (GXmlDomNode*) _tmp16_;
				_tmp17_ = node;
				_tmp18_ = p;
				_tmp19_ = gxml_dom_node_get_node_name (_tmp18_);
				_tmp20_ = _tmp19_;
				_tmp21_ = _tmp20_;
				_tmp22_ = p;
				_tmp23_ = gxml_dom_node_get_node_value (_tmp22_);
				_tmp24_ = _tmp23_;
				_tmp25_ = _tmp24_;
				gxml_dom_element_set_attribute (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement), _tmp21_, _tmp25_, &_inner_error_);
				_g_free0 (_tmp25_);
				_g_free0 (_tmp21_);
				if (G_UNLIKELY (_inner_error_ != NULL)) {
					gboolean _tmp26_ = FALSE;
					g_propagate_error (error, _inner_error_);
					_g_object_unref0 (p);
					_g_object_unref0 (_p_it);
					return _tmp26_;
				}
				_g_object_unref0 (p);
			}
			_g_object_unref0 (_p_it);
		}
		_tmp27_ = deep;
		if (!_tmp27_) {
			result = TRUE;
			return result;
		}
		{
			GXmlDomNodeList* _c_list = NULL;
			GXmlDomNode* _tmp28_ = NULL;
			GXmlDomNodeList* _tmp29_ = NULL;
			GXmlDomNodeList* _tmp30_ = NULL;
			gint _c_size = 0;
			GXmlDomNodeList* _tmp31_ = NULL;
			gint _tmp32_ = 0;
			gint _tmp33_ = 0;
			gint _c_index = 0;
			_tmp28_ = source;
			_tmp29_ = gxml_dom_node_get_child_nodes (_tmp28_);
			_tmp30_ = _tmp29_;
			_c_list = _tmp30_;
			_tmp31_ = _c_list;
			_tmp32_ = gee_collection_get_size ((GeeCollection*) _tmp31_);
			_tmp33_ = _tmp32_;
			_c_size = _tmp33_;
			_c_index = -1;
			while (TRUE) {
				gint _tmp34_ = 0;
				gint _tmp35_ = 0;
				gint _tmp36_ = 0;
				GXmlDomNode* c = NULL;
				GXmlDomNodeList* _tmp37_ = NULL;
				gint _tmp38_ = 0;
				gpointer _tmp39_ = NULL;
				GXmlDomNode* _tmp40_ = NULL;
				GXmlDomNode* _tmp63_ = NULL;
				_tmp34_ = _c_index;
				_c_index = _tmp34_ + 1;
				_tmp35_ = _c_index;
				_tmp36_ = _c_size;
				if (!(_tmp35_ < _tmp36_)) {
					break;
				}
				_tmp37_ = _c_list;
				_tmp38_ = _c_index;
				_tmp39_ = gee_list_get ((GeeList*) _tmp37_, _tmp38_);
				c = (GXmlDomNode*) _tmp39_;
				_tmp40_ = c;
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp40_, GXML_TYPE_DOM_ELEMENT)) {
					GXmlDomNode* _tmp41_ = NULL;
					gchar* _tmp42_ = NULL;
					gchar* _tmp43_ = NULL;
					gchar* _tmp44_ = NULL;
					gboolean _tmp45_ = FALSE;
					_tmp41_ = c;
					_tmp42_ = gxml_dom_node_get_node_name (_tmp41_);
					_tmp43_ = _tmp42_;
					_tmp44_ = _tmp43_;
					_tmp45_ = _tmp44_ == NULL;
					_g_free0 (_tmp44_);
					if (_tmp45_) {
						_g_object_unref0 (c);
						continue;
					}
					{
						GXmlDomElement* e = NULL;
						GXmlDomDocument* _tmp46_ = NULL;
						GXmlDomNode* _tmp47_ = NULL;
						gchar* _tmp48_ = NULL;
						gchar* _tmp49_ = NULL;
						gchar* _tmp50_ = NULL;
						GXmlDomElement* _tmp51_ = NULL;
						GXmlDomElement* _tmp52_ = NULL;
						GXmlDomNode* _tmp53_ = NULL;
						GXmlDomNodeList* _tmp54_ = NULL;
						GXmlDomNodeList* _tmp55_ = NULL;
						GXmlDomNodeList* _tmp56_ = NULL;
						GXmlDomElement* _tmp57_ = NULL;
						GXmlDomDocument* _tmp58_ = NULL;
						GXmlDomElement* _tmp59_ = NULL;
						GXmlDomNode* _tmp60_ = NULL;
						gboolean _tmp61_ = FALSE;
						_tmp46_ = doc;
						_tmp47_ = c;
						_tmp48_ = gxml_dom_node_get_node_name (_tmp47_);
						_tmp49_ = _tmp48_;
						_tmp50_ = _tmp49_;
						_tmp51_ = gxml_dom_document_create_element (_tmp46_, _tmp50_, &_inner_error_);
						_tmp52_ = _tmp51_;
						_g_free0 (_tmp50_);
						e = _tmp52_;
						if (G_UNLIKELY (_inner_error_ != NULL)) {
							goto __catch13_g_error;
						}
						_tmp53_ = node;
						_tmp54_ = gxml_dom_node_get_child_nodes (_tmp53_);
						_tmp55_ = _tmp54_;
						_tmp56_ = _tmp55_;
						_tmp57_ = e;
						gee_collection_add ((GeeCollection*) _tmp56_, (GXmlDomNode*) _tmp57_);
						_g_object_unref0 (_tmp56_);
						_tmp58_ = doc;
						_tmp59_ = e;
						_tmp60_ = c;
						_tmp61_ = deep;
						gxml_dom_node_copy (_tmp58_, (GXmlDomNode*) _tmp59_, _tmp60_, _tmp61_, &_inner_error_);
						if (G_UNLIKELY (_inner_error_ != NULL)) {
							_g_object_unref0 (e);
							goto __catch13_g_error;
						}
						_g_object_unref0 (e);
					}
					goto __finally13;
					__catch13_g_error:
					{
						g_clear_error (&_inner_error_);
						_inner_error_ = NULL;
					}
					__finally13:
					if (G_UNLIKELY (_inner_error_ != NULL)) {
						gboolean _tmp62_ = FALSE;
						g_propagate_error (error, _inner_error_);
						_g_object_unref0 (c);
						_g_object_unref0 (_c_list);
						return _tmp62_;
					}
				}
				_tmp63_ = c;
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp63_, GXML_TYPE_DOM_TEXT)) {
					GXmlDomNode* _tmp64_ = NULL;
					gchar* _tmp65_ = NULL;
					gchar* _tmp66_ = NULL;
					gchar* _tmp67_ = NULL;
					gboolean _tmp68_ = FALSE;
					_tmp64_ = c;
					_tmp65_ = gxml_dom_character_data_get_data ((GXmlDomCharacterData*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp64_, GXML_TYPE_DOM_TEXT) ? ((GXmlDomText*) _tmp64_) : NULL));
					_tmp66_ = _tmp65_;
					_tmp67_ = _tmp66_;
					_tmp68_ = _tmp67_ == NULL;
					_g_free0 (_tmp67_);
					if (_tmp68_) {
						const gchar* _tmp69_ = NULL;
						_tmp69_ = _ ("Text node with NULL string");
						g_warning ("DomNode.vala:150: %s", _tmp69_);
						_g_object_unref0 (c);
						continue;
					}
					{
						GXmlDomText* t = NULL;
						GXmlDomDocument* _tmp70_ = NULL;
						GXmlDomNode* _tmp71_ = NULL;
						gchar* _tmp72_ = NULL;
						gchar* _tmp73_ = NULL;
						gchar* _tmp74_ = NULL;
						GXmlDomText* _tmp75_ = NULL;
						GXmlDomText* _tmp76_ = NULL;
						GXmlDomNode* _tmp77_ = NULL;
						GXmlDomNodeList* _tmp78_ = NULL;
						GXmlDomNodeList* _tmp79_ = NULL;
						GXmlDomNodeList* _tmp80_ = NULL;
						GXmlDomText* _tmp81_ = NULL;
						_tmp70_ = doc;
						_tmp71_ = c;
						_tmp72_ = gxml_dom_character_data_get_data ((GXmlDomCharacterData*) (G_TYPE_CHECK_INSTANCE_TYPE (_tmp71_, GXML_TYPE_DOM_TEXT) ? ((GXmlDomText*) _tmp71_) : NULL));
						_tmp73_ = _tmp72_;
						_tmp74_ = _tmp73_;
						_tmp75_ = gxml_dom_document_create_text_node (_tmp70_, _tmp74_, &_inner_error_);
						_tmp76_ = _tmp75_;
						_g_free0 (_tmp74_);
						t = _tmp76_;
						if (G_UNLIKELY (_inner_error_ != NULL)) {
							goto __catch14_g_error;
						}
						_tmp77_ = node;
						_tmp78_ = gxml_dom_node_get_child_nodes (_tmp77_);
						_tmp79_ = _tmp78_;
						_tmp80_ = _tmp79_;
						_tmp81_ = t;
						gee_collection_add ((GeeCollection*) _tmp80_, (GXmlDomNode*) _tmp81_);
						_g_object_unref0 (_tmp80_);
						_g_object_unref0 (t);
					}
					goto __finally14;
					__catch14_g_error:
					{
						GError* e = NULL;
						const gchar* _tmp82_ = NULL;
						e = _inner_error_;
						_inner_error_ = NULL;
						_tmp82_ = _ ("Can't copy child text node");
						g_warning ("DomNode.vala:157: %s", _tmp82_);
						_g_error_free0 (e);
					}
					__finally14:
					if (G_UNLIKELY (_inner_error_ != NULL)) {
						gboolean _tmp83_ = FALSE;
						g_propagate_error (error, _inner_error_);
						_g_object_unref0 (c);
						_g_object_unref0 (_c_list);
						return _tmp83_;
					}
				}
				_g_object_unref0 (c);
			}
			_g_object_unref0 (_c_list);
		}
	}
	result = FALSE;
	return result;
}


GXmlDomNodeNodeType gxml_dom_node_get_node_type (GXmlDomNode* self) {
	g_return_val_if_fail (self != NULL, 0);
	return GXML_DOM_NODE_GET_INTERFACE (self)->get_node_type (self);
}


gchar* gxml_dom_node_get_node_name (GXmlDomNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_DOM_NODE_GET_INTERFACE (self)->get_node_name (self);
}


const gchar* gxml_dom_node_get_base_uri (GXmlDomNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_DOM_NODE_GET_INTERFACE (self)->get_base_uri (self);
}


GXmlDomDocument* gxml_dom_node_get_owner_document (GXmlDomNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_DOM_NODE_GET_INTERFACE (self)->get_owner_document (self);
}


void gxml_dom_node_set_owner_document (GXmlDomNode* self, GXmlDomDocument* value) {
	g_return_if_fail (self != NULL);
	GXML_DOM_NODE_GET_INTERFACE (self)->set_owner_document (self, value);
}


GXmlDomNode* gxml_dom_node_get_parent_node (GXmlDomNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_DOM_NODE_GET_INTERFACE (self)->get_parent_node (self);
}


GXmlDomElement* gxml_dom_node_get_parent_element (GXmlDomNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_DOM_NODE_GET_INTERFACE (self)->get_parent_element (self);
}


GXmlDomNodeList* gxml_dom_node_get_child_nodes (GXmlDomNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_DOM_NODE_GET_INTERFACE (self)->get_child_nodes (self);
}


GXmlDomNode* gxml_dom_node_get_first_child (GXmlDomNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_DOM_NODE_GET_INTERFACE (self)->get_first_child (self);
}


GXmlDomNode* gxml_dom_node_get_last_child (GXmlDomNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_DOM_NODE_GET_INTERFACE (self)->get_last_child (self);
}


GXmlDomNode* gxml_dom_node_get_previous_sibling (GXmlDomNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_DOM_NODE_GET_INTERFACE (self)->get_previous_sibling (self);
}


GXmlDomNode* gxml_dom_node_get_next_sibling (GXmlDomNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_DOM_NODE_GET_INTERFACE (self)->get_next_sibling (self);
}


gchar* gxml_dom_node_get_node_value (GXmlDomNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_DOM_NODE_GET_INTERFACE (self)->get_node_value (self);
}


void gxml_dom_node_set_node_value (GXmlDomNode* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_DOM_NODE_GET_INTERFACE (self)->set_node_value (self, value);
}


gchar* gxml_dom_node_get_text_content (GXmlDomNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_DOM_NODE_GET_INTERFACE (self)->get_text_content (self);
}


void gxml_dom_node_set_text_content (GXmlDomNode* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_DOM_NODE_GET_INTERFACE (self)->set_text_content (self, value);
}


static void gxml_dom_node_base_init (GXmlDomNodeIface * iface) {
	static gboolean initialized = FALSE;
	if (!initialized) {
		initialized = TRUE;
		g_object_interface_install_property (iface, g_param_spec_enum ("node-type", "node-type", "node-type", GXML_DOM_NODE_TYPE_NODE_TYPE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
		g_object_interface_install_property (iface, g_param_spec_string ("node-name", "node-name", "node-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
		g_object_interface_install_property (iface, g_param_spec_string ("base-uri", "base-uri", "base-uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("owner-document", "owner-document", "owner-document", GXML_TYPE_DOM_DOCUMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
		g_object_interface_install_property (iface, g_param_spec_object ("parent-node", "parent-node", "parent-node", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("parent-element", "parent-element", "parent-element", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("child-nodes", "child-nodes", "child-nodes", GXML_TYPE_DOM_NODE_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("first-child", "first-child", "first-child", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("last-child", "last-child", "last-child", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("previous-sibling", "previous-sibling", "previous-sibling", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
		g_object_interface_install_property (iface, g_param_spec_object ("next-sibling", "next-sibling", "next-sibling", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
		g_object_interface_install_property (iface, g_param_spec_string ("node-value", "node-value", "node-value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		g_object_interface_install_property (iface, g_param_spec_string ("text-content", "text-content", "text-content", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
		iface->clone_node = gxml_dom_node_real_clone_node;
	}
}


/**
 * Base interface for all DOM4 implementations
 */
GType gxml_dom_node_get_type (void) {
	static volatile gsize gxml_dom_node_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_dom_node_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlDomNodeIface), (GBaseInitFunc) gxml_dom_node_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType gxml_dom_node_type_id;
		gxml_dom_node_type_id = g_type_register_static (G_TYPE_INTERFACE, "GXmlDomNode", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (gxml_dom_node_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (gxml_dom_node_type_id, GXML_TYPE_DOM_EVENT_TARGET);
		g_once_init_leave (&gxml_dom_node_type_id__volatile, gxml_dom_node_type_id);
	}
	return gxml_dom_node_type_id__volatile;
}


GQuark gxml_dom_error_quark (void) {
	return g_quark_from_static_string ("gxml_dom_error-quark");
}


gchar* gxml_dom_error_name_get_name (GXmlDomErrorName* self, gint error_code) {
	gchar* result = NULL;
	gchar* _tmp14_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	{
		GeeIterator* _k_it = NULL;
		GeeHashMap* _tmp0_ = NULL;
		GeeSet* _tmp1_ = NULL;
		GeeSet* _tmp2_ = NULL;
		GeeSet* _tmp3_ = NULL;
		GeeIterator* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
		_tmp0_ = self->priv->names;
		_tmp1_ = gee_abstract_map_get_keys ((GeeAbstractMap*) _tmp0_);
		_tmp2_ = _tmp1_;
		_tmp3_ = _tmp2_;
		_tmp4_ = gee_iterable_iterator ((GeeIterable*) _tmp3_);
		_tmp5_ = _tmp4_;
		_g_object_unref0 (_tmp3_);
		_k_it = _tmp5_;
		while (TRUE) {
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			gchar* k = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			GeeHashMap* _tmp10_ = NULL;
			const gchar* _tmp11_ = NULL;
			gpointer _tmp12_ = NULL;
			gint _tmp13_ = 0;
			_tmp6_ = _k_it;
			_tmp7_ = gee_iterator_next (_tmp6_);
			if (!_tmp7_) {
				break;
			}
			_tmp8_ = _k_it;
			_tmp9_ = gee_iterator_get (_tmp8_);
			k = (gchar*) _tmp9_;
			_tmp10_ = self->priv->names;
			_tmp11_ = k;
			_tmp12_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp10_, _tmp11_);
			_tmp13_ = error_code;
			if (((gint) ((gintptr) _tmp12_)) == _tmp13_) {
				result = k;
				_g_object_unref0 (_k_it);
				return result;
			}
			_g_free0 (k);
		}
		_g_object_unref0 (_k_it);
	}
	_tmp14_ = g_strdup ("");
	result = _tmp14_;
	return result;
}


gint gxml_dom_error_name_get_code (GXmlDomErrorName* self, const gchar* error_name) {
	gint result = 0;
	GeeHashMap* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	GeeHashMap* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gpointer _tmp5_ = NULL;
	g_return_val_if_fail (self != NULL, 0);
	g_return_val_if_fail (error_name != NULL, 0);
	_tmp0_ = self->priv->names;
	_tmp1_ = error_name;
	_tmp2_ = gee_abstract_map_has_key ((GeeAbstractMap*) _tmp0_, _tmp1_);
	if (!_tmp2_) {
		result = 0;
		return result;
	}
	_tmp3_ = self->priv->names;
	_tmp4_ = error_name;
	_tmp5_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp3_, _tmp4_);
	result = (gint) ((gintptr) _tmp5_);
	return result;
}


GXmlDomErrorName* gxml_dom_error_name_construct (GType object_type) {
	GXmlDomErrorName * self = NULL;
	self = (GXmlDomErrorName*) g_object_new (object_type, NULL);
	return self;
}


GXmlDomErrorName* gxml_dom_error_name_new (void) {
	return gxml_dom_error_name_construct (GXML_TYPE_DOM_ERROR_NAME);
}


static GObject * gxml_dom_error_name_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GXmlDomErrorName * self;
	GeeHashMap* _tmp0_ = NULL;
	GeeHashMap* _tmp1_ = NULL;
	GeeHashMap* _tmp2_ = NULL;
	GeeHashMap* _tmp3_ = NULL;
	GeeHashMap* _tmp4_ = NULL;
	GeeHashMap* _tmp5_ = NULL;
	GeeHashMap* _tmp6_ = NULL;
	GeeHashMap* _tmp7_ = NULL;
	GeeHashMap* _tmp8_ = NULL;
	GeeHashMap* _tmp9_ = NULL;
	GeeHashMap* _tmp10_ = NULL;
	GeeHashMap* _tmp11_ = NULL;
	GeeHashMap* _tmp12_ = NULL;
	GeeHashMap* _tmp13_ = NULL;
	GeeHashMap* _tmp14_ = NULL;
	GeeHashMap* _tmp15_ = NULL;
	GeeHashMap* _tmp16_ = NULL;
	GeeHashMap* _tmp17_ = NULL;
	GeeHashMap* _tmp18_ = NULL;
	GeeHashMap* _tmp19_ = NULL;
	GeeHashMap* _tmp20_ = NULL;
	GeeHashMap* _tmp21_ = NULL;
	parent_class = G_OBJECT_CLASS (gxml_dom_error_name_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_DOM_ERROR_NAME, GXmlDomErrorName);
	_tmp0_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp0_, "IndexSizeError", (gpointer) ((gintptr) 1));
	_tmp1_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp1_, "HierarchyRequestError", (gpointer) ((gintptr) 3));
	_tmp2_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp2_, "WrongDocumentError", (gpointer) ((gintptr) 4));
	_tmp3_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp3_, "InvalidCharacterError", (gpointer) ((gintptr) 5));
	_tmp4_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp4_, "NoModificationAllowedError", (gpointer) ((gintptr) 7));
	_tmp5_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp5_, "NotFoundError", (gpointer) ((gintptr) 8));
	_tmp6_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp6_, "NotSupportedError", (gpointer) ((gintptr) 9));
	_tmp7_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp7_, "InvalidStateError", (gpointer) ((gintptr) 11));
	_tmp8_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp8_, "SyntaxError", (gpointer) ((gintptr) 12));
	_tmp9_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp9_, "InvalidModificationError", (gpointer) ((gintptr) 13));
	_tmp10_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp10_, "NamespaceError", (gpointer) ((gintptr) 14));
	_tmp11_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp11_, "InvalidAccessError", (gpointer) ((gintptr) 15));
	_tmp12_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp12_, "SecurityError", (gpointer) ((gintptr) 18));
	_tmp13_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp13_, "NetworkError", (gpointer) ((gintptr) 19));
	_tmp14_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp14_, "AbortError", (gpointer) ((gintptr) 20));
	_tmp15_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp15_, "URLMismatchError", (gpointer) ((gintptr) 21));
	_tmp16_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp16_, "QuotaExceededError", (gpointer) ((gintptr) 22));
	_tmp17_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp17_, "TimeoutError", (gpointer) ((gintptr) 23));
	_tmp18_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp18_, "InvalidNodeTypeError", (gpointer) ((gintptr) 24));
	_tmp19_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp19_, "DataCloneError", (gpointer) ((gintptr) 25));
	_tmp20_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp20_, "EncodingError", (gpointer) ((gintptr) -1));
	_tmp21_ = self->priv->names;
	gee_abstract_map_set ((GeeAbstractMap*) _tmp21_, "NotReadableError", (gpointer) ((gintptr) -2));
	return obj;
}


static void gxml_dom_error_name_class_init (GXmlDomErrorNameClass * klass) {
	gxml_dom_error_name_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (GXmlDomErrorNamePrivate));
	G_OBJECT_CLASS (klass)->constructor = gxml_dom_error_name_constructor;
	G_OBJECT_CLASS (klass)->finalize = gxml_dom_error_name_finalize;
}


static void gxml_dom_error_name_instance_init (GXmlDomErrorName * self) {
	GeeHashMap* _tmp0_ = NULL;
	self->priv = GXML_DOM_ERROR_NAME_GET_PRIVATE (self);
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_INT, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
	self->priv->names = _tmp0_;
}


static void gxml_dom_error_name_finalize (GObject* obj) {
	GXmlDomErrorName * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_DOM_ERROR_NAME, GXmlDomErrorName);
	_g_object_unref0 (self->priv->names);
	G_OBJECT_CLASS (gxml_dom_error_name_parent_class)->finalize (obj);
}


GType gxml_dom_error_name_get_type (void) {
	static volatile gsize gxml_dom_error_name_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_dom_error_name_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlDomErrorNameClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_dom_error_name_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlDomErrorName), 0, (GInstanceInitFunc) gxml_dom_error_name_instance_init, NULL };
		GType gxml_dom_error_name_type_id;
		gxml_dom_error_name_type_id = g_type_register_static (G_TYPE_OBJECT, "GXmlDomErrorName", &g_define_type_info, 0);
		g_once_init_leave (&gxml_dom_error_name_type_id__volatile, gxml_dom_error_name_type_id);
	}
	return gxml_dom_error_name_type_id__volatile;
}



